@@ -71,7 +71,7 @@ def write_fasta(file, accession, sequence):
     """
     file.write('>{}\n'.format(accession))
     if len(sequence) <= 70:
-        file.write('>{}\n'.format(sequence))
+        file.write('{}\n'.format(sequence))
     else:
         line_num_exact = len(sequence) / 70
         line_num = math.floor(line_num_exact)
@@ -225,6 +225,8 @@ def generateVN(tree, seqDict, seqLength):
     -------
     calculated variation number
     """
+    print('# Generating Variation Number ')
+
     variation_number = np.zeros((seqLength,), dtype=int)
     queue = []
     queue.append(tree)
@@ -242,15 +244,17 @@ def generateVN(tree, seqDict, seqLength):
                 queue.append(c)
     return variation_number
 
-def processVN(file, outputDir, accession_full=None, seqType='protein', aligned=False, alignTool='clustal'):
+def processVN(file, outputDir, reindex=False, accession_full=None, seqType='protein', aligned=False, alignTool='clustal', treeTool='paup'):
     """
 
     Parameters
     ----------
-    file : input file in fasta format
+    file : input file in fasta format (full path)
         
     outputDir : output directory
         
+    reindex: whether to reset the fasta identifier
+
     accession_full : accession number; if provided, will output variation number for this sequence without gaps
         
     seqType : nucleotide or protein
@@ -259,6 +263,8 @@ def processVN(file, outputDir, accession_full=None, seqType='protein', aligned=F
 
     alignTool: the alignment program to use. clustal: clustalo; mafft: mafft
 
+    treeTool: tool to generate phylogenetic tree; paup or fasttree
+
     Returns
     -------
     vn.txt
@@ -275,33 +281,69 @@ def processVN(file, outputDir, accession_full=None, seqType='protein', aligned=F
     ################################################################################
     in_file = open(file)
 
-    accession = ''
-    sequence = ''
     fastaDict = {}
-    for line in in_file:
-        line = line.rstrip()
-        if len(line) == 0:
-            continue
-
-        if '>' in line:
-            #if the first accession, initiate
-            if accession == '':
-                accession = re.search('>([A-Za-z0-9_]+.[0-9]+)', line)
-                accession = accession.group(0)[1:]
+    homoAccession = ''
+    if reindex:
+        accession = ''
+        accession1 = ''
+        sequence = ''
+        accessionCount = 1
+        accessionDict = {}
+        for line in in_file:
+            line = line.rstrip()
+            if len(line) == 0:
                 continue
 
-            #store accession-sequence pair in fastaDict
-            sequence = replaceAA(sequence, seqType)
-            fastaDict[accession] = sequence
-            sequence = ''
-            accession = re.search('>([A-Za-z0-9_]+.[0-9]+)', line)
-            accession = accession.group(0)[1:]
+            if '>' in line:
+                #if the first accession, initiate
+                if accession != '':
+                    #store accession-sequence pair in fastaDict
+                    sequence = replaceAA(sequence, seqType)
+                    fastaDict[accession1] = sequence
+                    sequence = ''
 
-        else:
-            sequence = sequence + line
+                accession = line[1:]
+                accession1 = 's' + str(accessionCount)
+                accessionDict[accession1] = accession
 
-    sequence = replaceAA(sequence, seqType)
-    fastaDict[accession] = sequence
+                if accession == accession_full:
+                    homoAccession = accession1
+                accessionCount += 1
+
+            else:
+                sequence = sequence + line
+
+        sequence = replaceAA(sequence, seqType)
+        fastaDict[accession1] = sequence
+        
+        outputFile = open('{}/accession.txt'.format(outputDir), 'w')
+        for key in accessionDict.keys():
+            outputFile.write('{}\t{}\n'.format(key, accessionDict[key]))
+        outputFile.close()
+    else:
+        accession = ''
+        sequence = ''
+        for line in in_file:
+            line = line.rstrip()
+            if len(line) == 0:
+                continue
+
+            if '>' in line:
+                #if the first accession, initiate
+                if accession != '':
+                    #store accession-sequence pair in fastaDict
+                    sequence = replaceAA(sequence, seqType)
+                    fastaDict[accession] = sequence
+                    sequence = ''
+
+                accession = line[1:]
+                if accession == accession_full:
+                    homoAccession = accession
+            else:
+                sequence = sequence + line
+
+        sequence = replaceAA(sequence, seqType)
+        fastaDict[accession] = sequence
     in_file.close()
 
     ################################################################################
@@ -321,7 +363,7 @@ def processVN(file, outputDir, accession_full=None, seqType='protein', aligned=F
             write_fasta(file1, key, fastaDict[key])
         file1.close()
         fastaDict.clear()
-    
+
         ################################################################################
         #                      run cluster omega on the fasta file
         ################################################################################
@@ -330,11 +372,11 @@ def processVN(file, outputDir, accession_full=None, seqType='protein', aligned=F
         #     --auto -v --force >/dev/null'.format(outputDir, accession_full, outputDir, accession_full))
         
         if alignTool=='clustal':
-            print('# Performing multiple sequence alignment using CLUSTALO\n')
+            print('# Performing multiple sequence alignment using CLUSTALO')
             os.system('clustalo -i {}/{}.fasta -o {}/{}_aligned.fasta \
                 --auto -v --force >/dev/null'.format(outputDir, accession_full, outputDir, accession_full))
         else:
-            print('# Performing multiple sequence alignment using MAFFT\n')
+            print('# Performing multiple sequence alignment using MAFFT')
             os.system('mafft --auto --quiet {}/{}.fasta > {}/{}_aligned.fasta'.format(outputDir, accession_full, outputDir, accession_full))
     
     ################################################################################
@@ -354,34 +396,37 @@ def processVN(file, outputDir, accession_full=None, seqType='protein', aligned=F
             if len(accession) > 0:
                 seqDict[accession] = seq
                 seq = ''
-
-            accession = line.replace('_', '')
-            accession = accession.replace('.', '')
-            accession = accession.replace('>', '')
-
+            accession = line[1:]
         else:
             seq = seq + line
 
     seqDict[accession] = seq
     file1.close()
 
-    ################################################################################
-    #                      convert fasta to nexus file
-    ################################################################################
-    nexusFile = '{}/{}.nex'.format(outputDir, accession_full)
-    writeNexus(nexusFile, seqDict, seqType)
+    if treeTool.lower() == 'paup':
+        print('# Generating phylogenetic tree using paup')
+        ################################################################################
+        #                      convert fasta to nexus file
+        ################################################################################
+        nexusFile = '{}/{}.nex'.format(outputDir, accession_full)
+        writeNexus(nexusFile, seqDict, seqType)
 
-    ################################################################################
-    #                                   run paup
-    ################################################################################
-    getTreeCMD(nexusFile, '{}/{}_getTree.cmd'.format(outputDir, accession_full))
-    os.system('paup {}/{}_getTree.cmd >/dev/null'.format(outputDir, accession_full))
+        ################################################################################
+        #                                   run paup
+        ################################################################################
+        getTreeCMD(nexusFile, '{}/{}_getTree.cmd'.format(outputDir, accession_full))
+        os.system('paup {}/{}_getTree.cmd >/dev/null'.format(outputDir, accession_full))
+    else:
+        print('# Generating phylogenetic tree using FastTree')
+
+        if seqType.lower() == 'protein':
+            os.system('FastTree -quiet {}/{}_aligned.fasta > {}/{}_tree.tree'.format(outputDir, accession_full, outputDir, accession_full))
+        else:
+            os.system('FastTree -quiet -nt {}/{}_aligned.fasta > {}/{}_tree.tree'.format(outputDir, accession_full, outputDir, accession_full))
 
     ################################################################################
     #                              Generate variation number
     ################################################################################
-    print('# Generating Variation Number for {}'.format(file))
-
     with open('{}/{}_aligned.fasta'.format(outputDir,accession_full)) as f:
         alist = [line.rstrip() for line in f]
     seqDict = {}
@@ -404,16 +449,14 @@ def processVN(file, outputDir, accession_full=None, seqType='protein', aligned=F
     if accession_full == '_accession':
         homoAccession = None
     else:
-        homoAccession = accession_full
-        homoAccession = homoAccession.replace('_', '')
-        homoAccession = homoAccession.replace('.', '')
         homoSeq = seqDict[homoAccession]
         
 
     ################################################################################
     #                       convert phylogenetic tree
     ################################################################################
-    Phylo.convert('{}/{}_trees.nex'.format(outputDir, accession_full), 'nexus', '{}/{}_tree.tree'.format(outputDir, accession_full), 'newick')
+    if treeTool.lower == 'paup':
+        Phylo.convert('{}/{}_trees.nex'.format(outputDir, accession_full), 'nexus', '{}/{}_tree.tree'.format(outputDir, accession_full), 'newick')
 
     f = open('{}/{}_tree.tree'.format(outputDir, accession_full), 'r')
     tree = f.readline()
